/*
 * Copyright (c) 2009, Red Hat Middleware LLC or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Middleware LLC.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.jboss.maven.util.logging;

import org.codehaus.plexus.logging.Logger;
import org.apache.maven.plugin.logging.Log;

/**
 * Acts as a bridge between a Plexus {@link Logger} and Maven plugin {@link Log} for the cases where we utilize Plexus
 * components which expect a {@link Logger} and we want to tie that logging back into the logging for our plugin.
 *
 * @author Steve Ebersole
 */
public class PlexusToMavenPluginLoggingBridge implements Logger {
	private final Log pluginLog;

	public PlexusToMavenPluginLoggingBridge(Log pluginLog) {
		this.pluginLog = pluginLog;
	}

	public void debug(String message) {
		pluginLog.debug( message );
	}

	public void debug(String message, Throwable throwable) {
		pluginLog.debug( message, throwable );
	}

	public boolean isDebugEnabled() {
		return pluginLog.isDebugEnabled();
	}

	public void info(String message) {
		pluginLog.info( message );
	}

	public void info(String message, Throwable throwable) {
		pluginLog.info( message, throwable );
	}

	public boolean isInfoEnabled() {
		return pluginLog.isInfoEnabled();
	}

	public void warn(String message) {
		pluginLog.warn( message );
	}

	public void warn(String message, Throwable throwable) {
		pluginLog.warn( message, throwable );
	}

	public boolean isWarnEnabled() {
		return pluginLog.isWarnEnabled();
	}

	public void error(String message) {
		pluginLog.error( message );
	}

	public void error(String message, Throwable throwable) {
		pluginLog.error( message, throwable );
	}

	public boolean isErrorEnabled() {
		return pluginLog.isErrorEnabled();
	}

	public void fatalError(String message) {
		pluginLog.error( message );
	}

	public void fatalError(String message, Throwable throwable) {
		pluginLog.error( message, throwable );
	}

	public boolean isFatalErrorEnabled() {
		return pluginLog.isErrorEnabled();
	}

	public Logger getChildLogger(String name) {
		return null;
	}

	public int getThreshold() {
		return -1;
	}

	public String getName() {
		return "Maven Plugin Logging Bridge";
	}
}
